@@ -8,7 +8,6 @@ use crate::{
     hash::Hash,
     instruction::{CompiledInstruction, Instruction, InstructionError},
     message::Message,
-    nonce::NONCED_TX_MARKER_IX_INDEX,
     program_utils::limited_deserialize,
     pubkey::Pubkey,
     short_vec,
@@ -99,19 +98,6 @@ pub enum TransactionError {
     /// Transaction processing left an account with an outstanding borrowed reference
     #[error("Transaction processing left an account with an outstanding borrowed reference")]
     AccountBorrowOutstanding,
-
-    #[error(
-        "Transaction could not fit into current block without exceeding the Max Block Cost Limit"
-    )]
-    WouldExceedMaxBlockCostLimit,
-
-    /// Transaction version is unsupported
-    #[error("Transaction version is unsupported")]
-    UnsupportedVersion,
-
-    /// Transaction loads a writable account that cannot be written
-    #[error("Transaction loads a writable account that cannot be written")]
-    InvalidWritableAccount,
 }
 
 pub type Result<T> = result::Result<T, TransactionError>;
@@ -401,7 +387,7 @@ impl Transaction {
             .collect()
     }
 
-    pub fn verify_precompiles(&self, libsecp256k1_0_5_upgrade_enabled: bool) -> Result<()> {
+    pub fn verify_precompiles(&self) -> Result<()> {
         for instruction in &self.message().instructions {
             // The Transaction may not be sanitized at this point
             if instruction.program_id_index as usize >= self.message().account_keys.len() {
@@ -416,11 +402,7 @@ impl Transaction {
                     .map(|instruction| instruction.data.as_ref())
                     .collect();
                 let data = &instruction.data;
-                let e = verify_eth_addresses(
-                    data,
-                    &instruction_datas,
-                    libsecp256k1_0_5_upgrade_enabled,
-                );
+                let e = verify_eth_addresses(data, &instruction_datas);
                 e.map_err(|_| TransactionError::InvalidAccountIndex)?;
             }
         }
@@ -473,11 +455,11 @@ pub fn uses_durable_nonce(tx: &Transaction) -> Option<&CompiledInstruction> {
     let message = tx.message();
     message
         .instructions
-        .get(NONCED_TX_MARKER_IX_INDEX as usize)
+        .get(0)
         .filter(|maybe_ix| {
             let prog_id_idx = maybe_ix.program_id_index as usize;
             match message.account_keys.get(prog_id_idx) {
-                Some(program_id) => system_program::check_id(&program_id),
+                Some(program_id) => system_program::check_id(program_id),
                 _ => false,
             }
         } && matches!(limited_deserialize(&maybe_ix.data), Ok(SystemInstruction::AdvanceNonceAccount))
@@ -986,7 +968,7 @@ mod tests {
         let (_, nonce_pubkey, tx) = nonced_transfer_tx();
         let nonce_ix = uses_durable_nonce(&tx).unwrap();
         assert_eq!(
-            get_nonce_pubkey_from_instruction(&nonce_ix, &tx),
+            get_nonce_pubkey_from_instruction(nonce_ix, &tx),
             Some(&nonce_pubkey),
         );
     }
